//	-------------------------------------------------------------------------
//
//	DIR.HPP
//
//	-------------------------------------------------------------------------
//
//	DESCRIPTION:	This file defines the DirString object and declares
//					some directory handling functions.
//
//	-------------------------------------------------------------------------

#ifndef __dir_hpp
#define __dir_hpp

#include "stddefns.hpp"
#include "strings.hpp"

#include "stdio.h"
#include "io.h"

// options for use in directory functions

#define dir_DirectoriesOnly	0x01
#define dir_FilesOnly		0x02
#define dir_AllFiles        0xFF

// by default, DirStrings are 512 chars long maximum

#define DIRSTRING_DEFAULT_LENGTH	512

// the DirString (DIRectory STRING) definition

class DirString : public String
	{
	public:
		DirString(const char* st) : String(st,DIRSTRING_DEFAULT_LENGTH) {}
		~DirString() {}

		// for setting appropriate bits of a DirString
		void SetFileName(const char* st);
		void SetDrive(const char* st);
		void SetPath(const char* st);
		void SetDirectory(const char* st);

		// note: Contents() is used to return the full string....
		String* GetFileName();	// returns the filename only. 	eg. "TEST.FIL"
		String* GetDrive();		// returns the drive only. 		eg. "D:"
		String*	GetPath();		// returns the path only.		eg. "\GAME\BMED\"
		String*	GetDirectory();	// returns the directory only.	eg.	"BMED"
	};

// returns true if a specified disk\path\filename combination exists
bool 	dir_FileExists(DirString* pathname);

// returns the number of files (of type attrib) existing in the current directory
int 	dir_FilesInDir(uint attrib);

// NOTE: the following functions allocate memory for a DirString, returning
//		 a pointer to the NEW'd object. After use, the DirString _must_ be
//		 deleted!

// builds and returns a string containing all 'attrib' files in the current directory
// eg. "A.DAT/B.DAT/C.DAT/ETC.ETC"
String* dir_ReadDirectory(uint attrib);

// builds and returns a string containing a list of disk drive names
// eg. "A:/B:/C:/D:"
String* dir_GetDriveNames();

// builds and returns a string containing the current path
// eg. "D:\RAILS\DATA\"
String*	dir_GetCurrentPath();

#endif