//	-------------------------------------------------------------------------
//
//	DOSFILE.HPP
//
//	-------------------------------------------------------------------------
//
//	DESCRIPTION:	This file defines the DOSFile object which is used to
//					access a standard dos file (binary or text of course).
//
//	-------------------------------------------------------------------------

#ifndef __dosfile_hpp
#define __dosfile_hpp

#include "stddefns.hpp"
#include "dir.hpp"

#include "stdio.h"
#include "io.h"

// error messages for the DOSFile object
#define dosfile_NoError				0
#define dosfile_FileNotFound		-1
#define dosfile_SeekError			-2
#define dosfile_FileIsWriteOnly		-3
#define dosfile_FileIsReadOnly		-4
#define dosfile_ReadError			-5
#define dosfile_WriteError			-6
#define dosfile_FileNotOpen			-7
#define dosfile_FileAlreadyOpen		-8
#define dosfile_FileAlreadyClosed	-9

// options used when opening the DOSFile
#define dosfile_READWRITE		0x0001	// read-write access
#define dosfile_READONLY		0x0002	// read-only access
#define dosfile_WRITEONLY		0x0004	// write-only access
#define dosfile_APPEND			0x0008	// append existing file
#define dosfile_CREATE			0x0010	// create new file (overwrites existing file)

// some options used for seeking positions in a DOSFile
#define	dosfile_SEEK_FROM_TOP		SEEK_SET	// seeks from top of file
#define dosfile_SEEK_FROM_CURRENT	SEEK_CUR	// seeks from current file position
#define dosfile_SEEK_FROM_END		SEEK_END	// seeks backwards from end of file

class DOSFile
	{
	protected:
		int  	fileError; 	 		// error value set by all file routines
		int		fileHandle;			// the handle for our DOSFile...
		uint 	fileOptions;		// the options for the DOSFile
		bool 	createdStr;			// we created DirString

	public:
		bool 	fileIsOpen;			// whether or not the DOSFile is open
		DirString* 	fileName;		// name of the DOSFile

		DOSFile(DirString* pathname,uint options); 	// defines the DOSFile with options
		DOSFile(const char* pathname,uint options);	// defines the DOSFile with options
		virtual ~DOSFile();									// close the DOSFile

		virtual long FileSize();
		virtual long FilePos();							// returns the current file pointer
		virtual int  Seek(ulong pos, uint startpos = dosfile_SEEK_FROM_TOP);
														// seek a specified position in the file
		virtual int  Open();							// open the file
		virtual int  Close();							// close the file
		virtual int  Read(char* data, long size);	// read from file
		virtual int  Write(char* data, long size); // write to file
		virtual int  Error() { return fileError; }		// returns result of last operation
		virtual bool Eof() { return eof(fileHandle); }	// return true if at End-of-file
	};


#endif